==> qtmclock_src-0.0.8.tar.gz: qtmclock_src-0.0.8/qtmclock/qtmclock_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="ja_JP">
<defaultcodec></defaultcodec>
<context>
    <name>@default</name>
    <message>
        <location filename="ThemeClockWidget.cpp" line="173"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
</context>
<context>
    <name>ClockSettingDialog</name>
    <message>
        <location filename="ClockSettingDialogForm.ui" line="13"/>
        <source>qtmclock: Setting</source>
        <translation>テーマ時計: 設定</translation>
    </message>
    <message>
        <location filename="ClockSettingDialogForm.ui" line="95"/>
        <source>&amp;Close</source>
        <translation>閉じる (&amp;C)</translation>
    </message>
    <message>
        <location filename="ClockSettingDialogForm.ui" line="27"/>
        <source>Scale</source>
        <translation>拡大率</translation>
    </message>
    <message>
        <location filename="ClockSettingDialogForm.ui" line="19"/>
        <source>View Config</source>
        <translation>外観設定</translation>
    </message>
    <message>
        <location filename="ClockSettingDialogForm.ui" line="47"/>
        <source>change view scale.</source>
        <translation>表示の拡大率を変更します.</translation>
    </message>
    <message>
        <location filename="ClockSettingDialogForm.ui" line="37"/>
        <source>100 %</source>
        <translation>100 %</translation>
    </message>
    <message>
        <location filename="ClockSettingDialog.cpp" line="43"/>
        <source>%1 %</source>
        <translation>%1 %</translation>
    </message>
</context>
<context>
    <name>QAction</name>
    <message>
        <location filename="ThemeClockWidget.cpp" line="172"/>
        <source>E&amp;xit</source>
        <translation>終了(&amp;x)</translation>
    </message>
    <message>
        <location filename="ThemeClockWidget.cpp" line="167"/>
        <source>Config</source>
        <translation>設定</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <location filename="ThemeClockDraw.cpp" line="54"/>
        <source>Drop theme file in this form.</source>
        <translation>テーマファイルを、このフォームにドロップして下さい。</translation>
    </message>
</context>
<context>
    <name>ThemeClockWidget</name>
    <message>
        <location filename="ThemeClockWidget.cpp" line="293"/>
        <source>qtmclock</source>
        <translation>qtmclock</translation>
    </message>
    <message>
        <location filename="ThemeClockWidget.cpp" line="294"/>
        <source>%1 is not correct theme file.</source>
        <translation>%1 はテーマファイルではありません。</translation>
    </message>
</context>
</TS>

==> qtmclock_src-0.0.9.tar.gz: qtmclock_src-0.0.9/qtmclock/qtmclock_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="ja_JP">
<context>
    <name>@default</name>
    <message>
        <location filename="ThemeClockWidget.cpp" line="173"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
</context>
<context>
    <name>ClockSettingDialog</name>
    <message>
        <location filename="ClockSettingDialogForm.ui" line="13"/>
        <source>qtmclock: Setting</source>
        <translation>テーマ時計: 設定</translation>
    </message>
    <message>
        <location filename="ClockSettingDialogForm.ui" line="95"/>
        <source>&amp;Close</source>
        <translation>閉じる (&amp;C)</translation>
    </message>
    <message>
        <location filename="ClockSettingDialogForm.ui" line="27"/>
        <source>Scale</source>
        <translation>拡大率</translation>
    </message>
    <message>
        <location filename="ClockSettingDialogForm.ui" line="19"/>
        <source>View Config</source>
        <translation>外観設定</translation>
    </message>
    <message>
        <location filename="ClockSettingDialogForm.ui" line="47"/>
        <source>change view scale.</source>
        <translation>表示の拡大率を変更します.</translation>
    </message>
    <message>
        <location filename="ClockSettingDialogForm.ui" line="37"/>
        <source>100 %</source>
        <translation>100 %</translation>
    </message>
    <message>
        <location filename="ClockSettingDialog.cpp" line="43"/>
        <source>%1 %</source>
        <translation>%1 %</translation>
    </message>
</context>
<context>
    <name>QAction</name>
    <message>
        <location filename="ThemeClockWidget.cpp" line="172"/>
        <source>E&amp;xit</source>
        <translation>終了(&amp;x)</translation>
    </message>
    <message>
        <location filename="ThemeClockWidget.cpp" line="167"/>
        <source>Config</source>
        <translation>設定</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <location filename="ThemeClockDraw.cpp" line="54"/>
        <source>Drop theme file in this form.</source>
        <translation>テーマファイルを、このフォームにドロップして下さい.</translation>
    </message>
</context>
<context>
    <name>ThemeClockWidget</name>
    <message>
        <location filename="ThemeClockWidget.cpp" line="293"/>
        <source>qtmclock</source>
        <translation>qtmclock</translation>
    </message>
    <message>
        <location filename="ThemeClockWidget.cpp" line="294"/>
        <source>%1 is not correct theme file.</source>
        <translation>%1 はテーマファイルではありません.</translation>
    </message>
</context>
</TS>
